MOLSystem2D

Struct MOLSystem2D 

pub struct MOLSystem2D<S: SparseScalar> { /* private fields */ }
2D Method of Lines system.

Converts a 2D PDE of the form u_t = L[u] + R(t, x, y, u) into an ODE system, where L is a linear spatial operator assembled as a sparse matrix and R is an optional nonlinear reaction term.

Implementations

Source

impl<S: SparseScalar> MOLSystem2D<S>

pub fn heat(grid: Grid2D<S>, alpha: S, bc: &BoundaryConditions2D<S>) -> Self

Create a 2D MOL system for the heat equation: u_t = alpha * laplacian(u).

pub fn laplacian(grid: Grid2D<S>, bc: &BoundaryConditions2D<S>) -> Self

Create a 2D MOL system for the Laplacian: u_t = laplacian(u).

pub fn with_operator( grid: Grid2D<S>, coeffs: &Operator2DCoefficients<S>, bc: &BoundaryConditions2D<S>, ) -> Self

Create a 2D MOL system with a general linear operator.

pub fn with_reaction<F>(self, reaction: F) -> Self
where F: Fn(S, S, S, S) -> S + Send + Sync + 'static,

Add a nonlinear reaction term R(t, x, y, u) to the system.

The full PDE becomes: u_t = L[u] + R(t, x, y, u).

pub fn grid(&self) -> &Grid2D<S>

Get the spatial grid.

pub fn n_interior(&self) -> usize

Number of interior points (ODE dimension).

pub fn build_full_solution(&self, u_interior: &[S]) -> Vec<S>

Build the full solution array including boundaries.

Interior values are stored in column-major order: u[jj * nx_int + ii]. The full array has nx*ny entries in the same column-major layout.