pub struct MOLSystem2D<S: SparseScalar> { /* private fields */ }Expand description
2D Method of Lines system.
Converts a 2D PDE of the form u_t = L[u] + R(t, x, y, u)
into an ODE system, where L is a linear spatial operator assembled
as a sparse matrix and R is an optional nonlinear reaction term.
Implementations
Sourceimpl<S: SparseScalar> MOLSystem2D<S>
impl<S: SparseScalar> MOLSystem2D<S>
Sourcepub fn heat(grid: Grid2D<S>, alpha: S, bc: &BoundaryConditions2D<S>) -> Self
pub fn heat(grid: Grid2D<S>, alpha: S, bc: &BoundaryConditions2D<S>) -> Self
Create a 2D MOL system for the heat equation: u_t = alpha * laplacian(u).
Sourcepub fn laplacian(grid: Grid2D<S>, bc: &BoundaryConditions2D<S>) -> Self
pub fn laplacian(grid: Grid2D<S>, bc: &BoundaryConditions2D<S>) -> Self
Create a 2D MOL system for the Laplacian: u_t = laplacian(u).
Sourcepub fn with_operator(
grid: Grid2D<S>,
coeffs: &Operator2DCoefficients<S>,
bc: &BoundaryConditions2D<S>,
) -> Self
pub fn with_operator( grid: Grid2D<S>, coeffs: &Operator2DCoefficients<S>, bc: &BoundaryConditions2D<S>, ) -> Self
Create a 2D MOL system with a general linear operator.
Sourcepub fn with_reaction<F>(self, reaction: F) -> Self
pub fn with_reaction<F>(self, reaction: F) -> Self
Add a nonlinear reaction term R(t, x, y, u) to the system.
The full PDE becomes: u_t = L[u] + R(t, x, y, u).
Sourcepub fn n_interior(&self) -> usize
pub fn n_interior(&self) -> usize
Number of interior points (ODE dimension).
Sourcepub fn build_full_solution(&self, u_interior: &[S]) -> Vec<S>
pub fn build_full_solution(&self, u_interior: &[S]) -> Vec<S>
Build the full solution array including boundaries.
Interior values are stored in column-major order: u[jj * nx_int + ii]. The full array has nx*ny entries in the same column-major layout.